@@ -2,7 +2,7 @@
  * ddcui command line parser
  */
 
-// Copyright (C) 2018-2022 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2018-2023 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <config.h>
@@ -13,21 +13,22 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-
-#include <QtCore/qglobal.h>
-#include <QtCore/qconfig.h>
-
+#include <syslog.h>
 #include <ddcutil_macros.h>
 #include <ddcutil_types.h>
 #include <ddcutil_c_api.h>
 
+#include "c_util/report_util.h"
 #include "c_util/string_util.h"
+
+// #include "base/ddcui_core.h"
 #include "base/ddcui_parms.h"
 #include "base/feature_list.h"
-#include "ddcui_cmd_parser.h"
 
-#include "ddcui_cmd_parser_aux.h"
-#include "ddcui_parsed_cmd.h"
+#include "cmdline/ddcui_cmd_parser_aux.h"
+#include "cmdline/ddcui_parsed_cmd.h"
+
+#include "ddcui_cmd_parser.h"
 
 
 // Variables used by callback function
@@ -100,6 +101,41 @@ gboolean post_parse_hook(
 }
 
 
+bool parse_ddcui_syslog_level(
+      const char *        sval,
+      Ddcui_Syslog_Level* result_loc)
+{
+   bool debug = false;
+   bool parsing_ok = true;
+   if (debug)
+      printf("(%s) sval=|%s|\n", __func__, sval);
+
+#ifdef REF
+   VNT(DDCA_SYSLOG_DEBUG,   "DEBUG"),
+   VNT(DDCA_SYSLOG_VERBOSE, "VERBOSE"),
+   VNT(DDCA_SYSLOG_INFO,    "INFO"),
+   VNT(DDCA_SYSLOG_NOTICE,  "NOTICE"),
+   VNT(DDCA_SYSLOG_WARNING, "WARN"),
+   VNT(DDCA_SYSLOG_ERROR,   "ERROR"),
+   VNT(DDCA_SYSLOG_NEVER,   "NEVER"),
+#endif
+
+   *result_loc = ddca_syslog_level_from_name(sval);
+   if (*result_loc == DDCA_SYSLOG_NOT_SET) {
+      parsing_ok = false;
+      // emit_parser_error(errmsgs, __func__, "Invalid syslog level: %s", sval );
+      // emit_parser_error(errmsgs, __func__, "Valid values are NEVER, ERROR, WARN, INFO, DEBUG");
+      fprintf(stderr, "Invalid syslog level: %s\n", sval );
+      fprintf(stderr, "Valid values are NEVER, ERROR, WARN, NOTICE, INFO, VERBOSE, DEBUG\n");
+   }
+   if (debug)
+      printf("(%s) Returning %s, *result_loc = %d\n",
+            __func__, sbool(parsing_ok), *result_loc);
+   return parsing_ok;
+}
+
+
+
 /** Primary parsing function
  *
  *  \param  argc      number of command line arguments
@@ -117,53 +153,58 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
    if (debug) {
       printf("(%s) Starting\n", __func__ );
 
-      printf("argc=%d\n", argc);
+      printf("(%s) argc=%d\n", __func__, argc);
       for (int ndx=0; ndx < argc; ndx++) {
-         printf("argv[%d] = |%s|\n", ndx, argv[ndx]);
+         printf("(%s) argv[%d] = |%s|\n", __func__, ndx, argv[ndx]);
       }
+      assert(argc == ntsa_length(argv));
 
       printf("(%s) prgname = %s, application_name = %s\n",
              __func__, g_get_prgname(), g_get_application_name() );
    }
-   // g_set_application_name("ddcui1");
 
    Parsed_Ddcui_Cmd * parsed_cmd = new_parsed_ddcui_cmd();
 
-   gboolean ddc_flag                = false;
-// gboolean nousb_flag              = false;
-   gboolean report_freed_excp_flag  = false;
-   gboolean timestamp_trace_flag    = false;
-   gboolean thread_id_trace_flag    = false;
-   gboolean version_flag            = false;
-   gboolean show_styles_flag        = false;
-   gboolean show_active_style_flag  = false;
-// gboolean use_latest_nc_values_true_set = false;
+// gboolean ddc_flag                       = false;
+// gboolean nousb_flag                     = false;
+// gboolean report_freed_excp_flag         = false;
+   gboolean timestamp_trace_flag           = false;
+   gboolean thread_id_trace_flag           = false;
+   gboolean version_flag                   = false;
+   gboolean show_styles_flag               = false;
+   gboolean show_active_style_flag         = false;
+// gboolean use_latest_nc_values_true_set  = false;
 // gboolean use_latest_nc_values_false_set = false;
-   gboolean hidpi_flag              = false;   //currently used only for testing
-   gchar**  cmd_and_args            = NULL;
-   gchar**  trace_classes           = NULL;
-   gchar**  trace_filenames         = NULL;
-   gchar**  trace_functions         = NULL;
+   gboolean hidpi_flag                     = false;   //currently used only for testing
+   gchar**  cmd_and_args                   = NULL;
+
+   DDCA_Syslog_Level syslog_level = DDCA_SYSLOG_INFO;
+   char *   syslog_work     = NULL;
+   gboolean disable_config_file            = false;
+// gboolean disable_libddcutil_config_file = false;
+   gboolean trace_to_syslog_flag           = false;   //???
+   gboolean watch_displays_flag     = true;   // the default
 
 #ifdef DISABLE_VIEW_OPTION
-   gchar*   view_work               = NULL;
+   gchar*   view_work                      = NULL;
 #endif
-   gchar*   nc_values_source_work   = NULL;
-   gchar*   feature_set_work        = NULL;
-   gchar*   custom_feature_set_work = NULL;
-   gboolean control_key_required    = false;
-   gboolean show_unsupported_features = false;
+   gchar*   nc_values_source_work          = NULL;
+   gchar*   feature_set_work               = NULL;
+   gchar*   custom_feature_set_work        = NULL;
+   gboolean control_key_required           = false;
+   gboolean show_unsupported_features      = false;
+   gchar**  libopts_pieces                 = NULL;
 
-   gboolean only_capabilities_true_set  = false;
-// gboolean only_capabilities_false_set = false;
-   gboolean all_capabilities_true_set   = false;
-// gboolean all_capabilities_false_set  = false;
+   gboolean only_capabilities_true_set     = false;
+// gboolean only_capabilities_false_set    = false;
+   gboolean all_capabilities_true_set      = false;
+// gboolean all_capabilities_false_set     = false;
 
-   gboolean force_slave_address_true_set = false;
-   gboolean force_slave_address_false_set = false;
+   gboolean force_slave_address_true_set   = false;
+   gboolean force_slave_address_false_set  = false;
 
-   gboolean debug_parse             = false;
-   gboolean parse_only              = false;
+   gboolean debug_parse                    = false;
+   gboolean parse_only                     = false;
 
    gboolean f1_flag        = false;
    gboolean f2_flag        = false;
@@ -173,97 +214,109 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
    gboolean f6_flag        = false;
 
    GOptionEntry public_option_entries[] = {
-   //  long_name short flags option-type          gpointer           description                    arg description
+   //  long_name short flags  option-type            gpointer           description                    arg description
    //  monitor selection options
 
-   // output control
-
-#ifdef DISABLED_LIBDDCUTIL_ONLY
-      {"nousb",  '\0',  0,    G_OPTION_ARG_NONE,     &nousb_flag,       "Do not detect USB devices", NULL},
-#endif
-
-
    // Options dialog
 
 #ifdef DISABLE_VIEW_OPTION
-      {"view",     '\0',   0, G_OPTION_ARG_STRING,   &view_work,            "Initial view",             "Summary|Capabilities|Features"},
+      {"view",      '\0',  0, G_OPTION_ARG_STRING,   &view_work,             "Initial view",             "Summary|Capabilities|Features"},
 #endif
       {"require-control-key",
-                   '\0',   0, G_OPTION_ARG_NONE,     &control_key_required, "Control key must be pressed to move slider", NULL},
+                   '\0',   0, G_OPTION_ARG_NONE,     &control_key_required,  "Control key must be pressed to move slider", NULL},
       {"nc-values-source",
-                   '\0',   0, G_OPTION_ARG_STRING,   &nc_values_source_work,  "Initial NC values source",   "MMCS|Capabilities|Both"},
+                   '\0',   0, G_OPTION_ARG_STRING,   &nc_values_source_work, "Initial NC values source",   "MMCS|Capabilities|Both"},
 
       {"feature-set",
-                   '\0',   0, G_OPTION_ARG_STRING,   &feature_set_work,  "Feature set selection",
+                   '\0',   0, G_OPTION_ARG_STRING,   &feature_set_work,      "Feature set selection",
                                                                                    "MMCS|Capabilities|Manufacturer|Color|Scan"},
-      // {"use-latest-nc-values",
-      //              '\0',   0, G_OPTION_ARG_NONE,     &use_latest_nc_values_true_set, "Use NC values from the latest MCCS version", NULL},
+//    {"use-latest-nc-values",
+//                 '\0',   0, G_OPTION_ARG_NONE,     &use_latest_nc_values_true_set, "Use NC values from the latest MCCS version", NULL},
 
       {"custom-feature-set",
-                  '\0',   0, G_OPTION_ARG_STRING,   &custom_feature_set_work, "User feature set definition",
+                   '\0',   0, G_OPTION_ARG_STRING,    &custom_feature_set_work, "User feature set definition",
                                                                     "comma separated list of feature codes"},
       {"show-unsupported",
-                   '\0',   0, G_OPTION_ARG_NONE,      &show_unsupported_features, "Show unsupported features", NULL},
+                   '\0',   0, G_OPTION_ARG_NONE,     &show_unsupported_features, "Show unsupported features", NULL},
       {"only-capabilities",
-                   '\0',   0, G_OPTION_ARG_NONE,      &only_capabilities_true_set, "Include only values in capabilities", NULL},
+                   '\0',   0, G_OPTION_ARG_NONE,     &only_capabilities_true_set, "Include only values in capabilities", NULL},
 //    {"not-only-capabilities",
 //                 '\0',  0, G_OPTION_ARG_NONE,      &only_capabilities_false_set, "Do not exclude values only in MCCS", NULL},
       {"all-capabilities",
-                   '\0',   0, G_OPTION_ARG_NONE,      &all_capabilities_true_set, "Include all values in capabilities", NULL},
-//      {"not-all-capabilities",
-//                     '\0', 0, G_OPTION_ARG_NONE,      &all_capabilities_false_set, "Negate include all values in capabilities", NULL},
+                   '\0',   0, G_OPTION_ARG_NONE,     &all_capabilities_true_set, "Include all values in capabilities", NULL},
+//    {"not-all-capabilities",
+//                 '\0', 0, G_OPTION_ARG_NONE,       &all_capabilities_false_set, "Negate include all values in capabilities", NULL},
 
 // Display selection
-      {"model",    '\0',   0, G_OPTION_ARG_STRING, &parsed_cmd->model,                "Model of default display",              NULL},
-//    {"bus",      '\0',   0, G_OPTION_ARG_INT,    &parsed_cmd->busno,    "I2C bus number",                        "integer"},
+      {"model",    '\0',   0, G_OPTION_ARG_STRING,   &parsed_cmd->model,                "Model of default display",              NULL},
+//    {"bus",      '\0',   0, G_OPTION_ARG_INT,      &parsed_cmd->busno,    "I2C bus number",                        "integer"},
+#ifdef DISABLED_LIBDDCUTIL_ONLY
+      {"nousb",    '\0',   0, G_OPTION_ARG_NONE,     &nousb_flag,       "Do not detect USB devices", NULL},
+#endif
 
 // Tuning
-      {"stats",   's',  G_OPTION_FLAG_OPTIONAL_ARG,
-                              G_OPTION_ARG_CALLBACK, stats_arg_func,    "Show performance statistics",  "TRIES|ERRORS|CALLS|ALL"},
-      {"ddc",     '\0', 0,    G_OPTION_ARG_NONE,     &ddc_flag,         "Report DDC protocol and data errors", NULL},
+      {"stats",    's',  G_OPTION_FLAG_OPTIONAL_ARG,
+                            G_OPTION_ARG_CALLBACK, stats_arg_func,    "Show performance statistics",  "TRIES|ERRORS|CALLS|ALL"},
+//    {"ddc",      '\0', 0, G_OPTION_ARG_NONE,     &ddc_flag,         "Report DDC protocol and data errors", NULL},
       {"force-slave-address",
-                  '\0', 0,    G_OPTION_ARG_NONE,     &force_slave_address_true_set, "Deprecated", NULL},
+                   '\0', 0, G_OPTION_ARG_NONE,     &force_slave_address_true_set, "Deprecated", NULL},
       {"disable-force-slave-address",
-                  '\0', 0,    G_OPTION_ARG_NONE,     &force_slave_address_false_set, "Deprecated", NULL},
+                   '\0', 0, G_OPTION_ARG_NONE,     &force_slave_address_false_set, "Deprecated", NULL},
 
 // Pre-GUI queries
-      {"styles",   '\0',   0, G_OPTION_ARG_NONE,     &show_styles_flag,     "List known styles",        NULL},
-      {"show-style", '\0', 0, G_OPTION_ARG_NONE,     &show_active_style_flag, "Show active style",      NULL},
-      {"version",  'V',    0, G_OPTION_ARG_NONE,     &version_flag,         "Show version information", NULL},
+      {"styles",   '\0', 0, G_OPTION_ARG_NONE,     &show_styles_flag,            "List known styles",   NULL},
+      {"show-style",'\0',0, G_OPTION_ARG_NONE,     &show_active_style_flag,      "Show active style",   NULL},
+
+// libddcutil options
+      {"libopts",  '\0', 0, G_OPTION_ARG_STRING_ARRAY, &libopts_pieces,  "libddcutil options",  "string"},
+      {"enable-watch-displays",
+                   '\0', 0, G_OPTION_ARG_NONE,     &watch_displays_flag, "Watch for display connections (default)", NULL},
+      {"disable-watch-displays", '\0', G_OPTION_FLAG_REVERSE,
+                            G_OPTION_ARG_NONE,     &watch_displays_flag, "Do not watch for display connections", NULL},
+
+// output control
+      {"disable-config-file",
+                   '\0', 0, G_OPTION_ARG_NONE,     &disable_config_file, "Ignore ddcutil config file", NULL},
+      {"noconfig", '\0', 0, G_OPTION_ARG_NONE,     &disable_config_file, "Ignore ddcutil config file", NULL},
+
+      {"syslog",   '\0', 0, G_OPTION_ARG_STRING,   &syslog_work,                    "system log level", "NONE, ERROR, WARN, INFO, NONE"},
+
+      {"version",  'V',  0, G_OPTION_ARG_NONE,     &version_flag,         "Show version information",   NULL},
       { NULL }
    };
 
    GOptionEntry development_options[] = {
 // debugging
-      {"excp",     '\0',   0, G_OPTION_ARG_NONE,     &report_freed_excp_flag,  "Report freed exceptions", NULL},
-      {"trace",    '\0',   0, G_OPTION_ARG_STRING_ARRAY, &trace_classes, "Trace a group",         "trace group name" },
-  //  {"trace",    '\0',   0, G_OPTION_ARG_STRING,   &tracework,         "Trace a group",          "comma separated list" },
-      {"trcfunc",  '\0',   0, G_OPTION_ARG_STRING_ARRAY, &trace_functions, "Trace a function",     "function name" },
-      {"trcfile",  '\0',   0, G_OPTION_ARG_STRING_ARRAY, &trace_filenames, "Trace a file",         "file name" },
+//    {"excp",     '\0',   0, G_OPTION_ARG_NONE,   &report_freed_excp_flag, "Report freed exceptions", NULL},
       {"timestamp",'\0',   0, G_OPTION_ARG_NONE,   &timestamp_trace_flag, "Prepend trace msgs with elapsed time",  NULL},
       {"ts",       '\0',   0, G_OPTION_ARG_NONE,   &timestamp_trace_flag, "Prepend trace msgs with elapsed time",  NULL},
       {"thread-id",'\0',   0, G_OPTION_ARG_NONE,   &thread_id_trace_flag, "Prepend trace msgs with thread id",     NULL},
       {"tid",      '\0',   0, G_OPTION_ARG_NONE,   &thread_id_trace_flag, "Prepend trace msgs with thread id",     NULL},
 
 // Debug parser
-      {"debug-parse", '\0', 0, G_OPTION_ARG_NONE,    &debug_parse,           "Show parse result",        NULL},
-      {"parse-only",  '\0', 0, G_OPTION_ARG_NONE,    &parse_only,            "Exit after parsing",       NULL},
+      {"debug-parse", '\0', 0, G_OPTION_ARG_NONE,  &debug_parse,          "Show parse result",        NULL},
+      {"parse-only",  '\0', 0, G_OPTION_ARG_NONE,  &parse_only,           "Exit after parsing",       NULL},
 
 // Other
       {"hidpi",    '\0',   0, G_OPTION_ARG_NONE,  &hidpi_flag,            "Test hidpi code", NULL},
 
 // Undocumented library flag options
-      {"f1",      '\0', 0,  G_OPTION_ARG_NONE,     &f1_flag,         "Special flag 1",    NULL},
-      {"f2",      '\0', 0,  G_OPTION_ARG_NONE,     &f2_flag,         "Special flag 2",    NULL},
-      {"f3",      '\0', 0,  G_OPTION_ARG_NONE,     &f3_flag,         "Special flag 3",    NULL},
-      {"f4",      '\0', 0,  G_OPTION_ARG_NONE,     &f4_flag,         "Special flag 4",    NULL},
-      {"f5",      '\0', 0,  G_OPTION_ARG_NONE,     &f5_flag,         "Special flag 5",    NULL},
-      {"f6",      '\0', 0,  G_OPTION_ARG_NONE,     &f6_flag,         "Special flag 6",    NULL},
+      {"f1",      '\0', 0,  G_OPTION_ARG_NONE,     &f1_flag,              "Special flag 1",    NULL},
+      {"f2",      '\0', 0,  G_OPTION_ARG_NONE,     &f2_flag,              "Special flag 2",    NULL},
+      {"f3",      '\0', 0,  G_OPTION_ARG_NONE,     &f3_flag,              "Special flag 3",    NULL},
+      {"f4",      '\0', 0,  G_OPTION_ARG_NONE,     &f4_flag,              "Special flag 4",    NULL},
+      {"f5",      '\0', 0,  G_OPTION_ARG_NONE,     &f5_flag,              "Special flag 5",    NULL},
+      {"f6",      '\0', 0,  G_OPTION_ARG_NONE,     &f6_flag,              "Special flag 6",    NULL},
+      {"i1",      '\0', 0,  G_OPTION_ARG_INT,      &parsed_cmd->i1,       "Special integer 1", NULL},
+      {"i2",      '\0', 0,  G_OPTION_ARG_INT,      &parsed_cmd->i2,       "Special integer 2", NULL},
+
+  //    {G_OPTION_REMAINING,
+  //                    '\0', 0,  G_OPTION_ARG_STRING_ARRAY, &cmd_and_args, NULL,   NULL},
 
       { NULL }
    };
 
-#ifdef UNUSED
+#ifdef DOESNT_WORK
    GOptionEntry final_options[] = {
      // collect to verify that does not exist
       {G_OPTION_REMAINING,
@@ -282,10 +335,19 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
    g_option_group_add_entries(development_option_group, development_options);
    g_option_group_set_parse_hooks(development_option_group, pre_parse_hook, post_parse_hook);
 
+#ifdef DOESNT_WORK
+   GOptionGroup * remainder_group =
+   g_option_group_new("remainder", "Command sink", "Should be empty", NULL, NULL);
+   g_option_group_add_entries(remainder_group, final_options);
+#endif
+
    GError* error = NULL;
    GOptionContext* context = g_option_context_new("- graphical interface to ddcutil");
    g_option_context_add_main_entries(context, public_option_entries, NULL);
    g_option_context_add_group(context, development_option_group);
+#ifdef DOESNT_WORK
+   g_option_context_add_group(context, remainder_group);
+#endif
 
    g_option_context_set_help_enabled(context, true);
    // bool ok = false;
@@ -305,28 +367,56 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
    char ** mangleable_argv = argv;
    if (debug) {
       printf("(%s) Before g_option_context_parse_strv(), mangleable_argv:\n", __func__);
-      ntsa_show(mangleable_argv);
+      rpt_ntsa(mangleable_argv, 3);
    }
+   char * combined = strjoin((const char**)(mangleable_argv+1), ntsa_length(mangleable_argv)-1, " ");
+   printf("ddcui: Applying combined options: %s\n", combined);
+   syslog(LOG_NOTICE,"Applying combined ddcui options: %s",   combined);
+   free(combined);
    bool ok = g_option_context_parse_strv(context, &mangleable_argv, &error);
    if (!ok) {
       if (error) {
-         fprintf(stderr, "ddcui option parsing failed: %s\n", error->message);
+         fprintf(stderr,  "ddcui option parsing failed: %s\n", error->message);
+         syslog(LOG_CRIT, "ddcui option parsing failed: %s",   error->message);
          g_error_free(error);
       }
       else {
-         fprintf(stderr, "ddcui option parsing failed.\n");
+         fprintf(stderr,  "ddcui option parsing failed.\n");
+         syslog(LOG_CRIT, "ddcui option parsing failed.");
       }
    }
-   if (debug) {
+
+   if (ntsa_length(mangleable_argv) > 1) {
+      char * remainder = strjoin((const char**)(mangleable_argv+1), ntsa_length(mangleable_argv)-1, " ");
+      fprintf(stderr, "Unrecognized: %s\n", remainder);
+      syslog(LOG_CRIT, "Unrecognized: %s\n", remainder);
+      free(remainder);
+      ok = false;
+   }
+
+   if (false) {
       printf("(%s) Freeing mangleable_argv=%p:\n", __func__, (void*)mangleable_argv);
-      ntsa_show(mangleable_argv);
+      rpt_ntsa(mangleable_argv, 3);
    }
    ntsa_free(mangleable_argv, true);
 
-   if (force_slave_address_true_set)
-      fprintf(stderr, "Deprecated option ignored: --force_slave_address\n");
-   if (force_slave_address_false_set)
-      fprintf(stderr, "Deprecated option ignored: --disable-force_slave_address\n");
+   if (force_slave_address_true_set) {
+      char * s = "Deprecated option ignored: --force_slave_address";
+      fprintf(stderr,     "%s\n", s);
+      syslog(LOG_WARNING, "%s",   s);
+   }
+   if (force_slave_address_false_set) {
+      char * s = "Deprecated option ignored: --disable-force_slave_address";
+      fprintf(stderr,     "%s\n", s);
+      syslog(LOG_WARNING, "%s",   s);
+   }
+
+   if (libopts_pieces) {
+      char * combined_libopts_pieces = strjoin((const char**)libopts_pieces, ntsa_length(libopts_pieces), " ");
+      parsed_cmd->library_options = combined_libopts_pieces;
+      ntsa_free(libopts_pieces, true);
+      // printf("Combined_libopts_pieces: |%s|\n", combined_libopts_pieces);
+   }
 
 #define SET_CMDFLAG(_bit, _flag) \
    do { \
@@ -335,10 +425,10 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
    } while(0)
 
    parsed_cmd->stats_types      = stats_work;
-   SET_CMDFLAG(CMD_FLAG_DDCDATA,           ddc_flag);
+// SET_CMDFLAG(CMD_FLAG_DDCDATA,           ddc_flag);
    SET_CMDFLAG(CMD_FLAG_TIMESTAMP_TRACE,   timestamp_trace_flag);
    SET_CMDFLAG(CMD_FLAG_THREAD_ID_TRACE,   thread_id_trace_flag);
-   SET_CMDFLAG(CMD_FLAG_REPORT_FREED_EXCP, report_freed_excp_flag);
+// SET_CMDFLAG(CMD_FLAG_REPORT_FREED_EXCP, report_freed_excp_flag);
 
 // SET_CMDFLAG(CMD_FLAG_NOUSB,             nousb_flag);
 
@@ -348,6 +438,8 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
    SET_CMDFLAG(CMD_FLAG_UI_REQUIRE_CONTROL_KEY, control_key_required);
    SET_CMDFLAG(CMD_FLAG_SHOW_UNSUPPORTED,       show_unsupported_features);
 // SET_CMDFLAG(CMD_FLAG_LATEST_NC_VALUE_NAMES,  use_latest_nc_values_true_set);   // n. not handling case where default is true
+   SET_CMDFLAG(CMD_FLAG_DISABLE_CONFIG_FILE, disable_config_file);
+   SET_CMDFLAG(CMD_FLAG_WATCH_DISPLAYS,      watch_displays_flag);
 
    SET_CMDFLAG(CMD_FLAG_F1,                f1_flag);
    SET_CMDFLAG(CMD_FLAG_F2,                f2_flag);
@@ -359,6 +451,19 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
    SET_CMDFLAG(CMD_FLAG_HIDPI,             hidpi_flag);
 #undef SET_CMDFLAG
 
+   if (syslog_work) {
+      Ddcui_Syslog_Level level;
+      bool this_ok = parse_ddcui_syslog_level(syslog_work, &level);
+      // printf("(%s) this_ok = %s\n", __func__, sbool(this_ok));
+      if (this_ok)
+         syslog_level = level;
+      else
+         ok = false;
+      free(syslog_work);
+   }
+   parsed_cmd->syslog_level = syslog_level;
+
+
    if (all_capabilities_true_set)
       parsed_cmd->include_all_capabilities_features = TRIVAL_TRUE;
 #ifdef TRIVAL
@@ -386,54 +491,23 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
       if (ddca_feature_list_count(flist) == 0) {
          ok = false;
          if (error_msgs) {
-            fprintf(stderr, "Errors in --custom-feature-set:\n");
+            char * s = "Errors in --custom-feature-set:";
+            fprintf(stderr, "%s\n", s);
+            syslog(LOG_CRIT, "%s", s);
             for (int ndx = 0; error_msgs[ndx]; ndx++) {
-               fprintf(stderr, "   %s\n", error_msgs[ndx]);
+               fprintf(stderr,  "   %s\n", error_msgs[ndx]);
+               syslog(LOG_CRIT, "   %s",   error_msgs[ndx]);
             }
             ntsa_free(error_msgs, true);
          }
          else {
-            fprintf(stderr, "Empty --custom-feature-set\n");
+            char * s = "Empty --custom-feature-set";
+            fprintf(stderr,  "%s\n", s);
+            syslog(LOG_CRIT, "%s",   s);
          }
       }
    }
 
-   // #ifdef MULTIPLE_TRACE
-      if (trace_classes) {
-         DDCA_Trace_Group traceClasses = 0x00;
-         int ndx = 0;
-         for (;trace_classes[ndx] != NULL; ndx++) {
-            char * token = g_ascii_strup(trace_classes[ndx], -1);   // n g_ascii_strup returns newly allocated string
-            // DBGMSG("token=|%s|", token);
-            if (strcmp(token, "ALL") == 0 || strcmp(token, "*") == 0) {
-               traceClasses = DDCA_TRC_ALL;   // 0xff
-            }
-            else {
-               // DBGMSG("token: |%s|", token);
-               DDCA_Trace_Group tg = ddca_trace_group_name_to_value(token);
-               // DBGMSG("tg=0x%02x", tg);
-               if (tg) {
-                  traceClasses |= tg;
-               }
-               else {
-                  fprintf(stderr, "Invalid trace group: %s\n", token);
-                  ok = false;
-               }
-           }
-           free(token);
-         }
-         // DBGMSG("traceClasses = 0x%02x", traceClasses);
-         parsed_cmd->traced_groups = traceClasses;
-      }
-   // #endif
-
-      if (trace_functions) {
-         parsed_cmd->traced_functions = trace_functions;
-      }
-      if (trace_filenames) {
-         parsed_cmd->traced_files = trace_filenames;
-      }
-
 #ifdef DISABLE_VIEW_OPTION
       if (view_work) {
          // printf("view_work = %p -> |%s|\n", view_work, view_work);
@@ -452,7 +526,9 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
          // printf("nc_values_source_work = %p -> |%s|\n", nc_values_source_work, nc_values_source_work);
          Parsed_NC_Values_Source src = find_nc_values_source_table_value(nc_values_source_work);
          if (src == NC_VALUES_SOURCE_UNSET) {
-            fprintf(stderr, "Unrecognized: %s\n", nc_values_source_work);
+            char * s = "Unrecognized: ";
+            fprintf(stderr, "%s%s\n", s, nc_values_source_work);
+            fprintf(stderr, "%s%s",   s, nc_values_source_work);
             ok = false;
          }
          else{
@@ -465,7 +541,8 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
       if (_NAME ## _work) {                          \
          _ENUM src = find_ ## _NAME ##_table_value(_NAME ## _work);            \
          if (src == _NOT_FOUND_VALUE) {                                        \
-            fprintf(stderr, "Unrecognized: %s\n", _NAME ## _work);             \
+            fprintf(stderr,  "Unrecognized: %s\n", _NAME ## _work);            \
+            syslog(LOG_CRIT, "Unrecognized: %s",   _NAME ## _work);            \
             ok = false;                                                        \
          }                                                                     \
          else{                                                                 \
@@ -480,14 +557,18 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
       if (parsed_cmd->feature_set != FS_UNSET &&
           ddca_feature_list_count(parsed_cmd->custom_feature_list) > 0)
       {
-         fprintf(stderr, "--feature-set and --custom-feature-set are mutually exclusive\n");
+         char * s = "--feature-set and --custom-feature-set are mutually exclusive";
+         fprintf(stderr,  "%s\n", s);
+         syslog(LOG_CRIT, "%s",   s);
          ok = false;
       }
 
       if (all_capabilities_true_set && only_capabilities_true_set) {
          if (parsed_cmd->feature_set != FS_CAPABILITIES) {
-            fprintf(stderr, "--all-capabilities and --only-capabilities are mutually exclusive"
-                            " except when --feature-set = CAPABILITIES\n");
+            char * s = "--all-capabilities and --only-capabilities are mutually exclusive"
+                            " except when --feature-set = CAPABILITIES";
+            fprintf(stderr,  "%s\n", s);
+            syslog(LOG_CRIT, "%s",   s);
             ok = false;
          }
       }
@@ -503,22 +584,13 @@ Parsed_Ddcui_Cmd * parse_ddcui_command(int argc, char * argv[]) {
          // }
 
          char * s = g_strjoinv(" ",cmd_and_args);
-         fprintf(stderr, "Unrecognized: %s\n", s);
+         fprintf(stderr,  "Unrecognized: %s\n", s);
+         syslog(LOG_CRIT, "Unrecognized: %s",   s);
          free(s);
          ok = false;
       }
 
    if (version_flag) {
-      printf("ddcui %s\n\n", DDCUI_VSTRING);
-      printf("Built using libddcutil version %d.%d.%d, Qt version %s\n",
-             DDCUTIL_VMAJOR, DDCUTIL_VMINOR, DDCUTIL_VMICRO, QT_VERSION_STR);
-      printf("Executing using libddcutil %s, Qt %s\n\n",
-             ddca_ddcutil_extended_version_string(), qVersion());
-      puts("Copyright (C) 2018-2022 Sanford Rockowitz");
-      puts("License GPLv2: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>");
-      puts("This is free software: you are free to change and redistribute it.");
-      puts("There is NO WARRANTY, to the extent permitted by law.");
-      exit(0);
    }
 
    // DBGMSF(debug, "Calling g_option_context_free(), context=%p...", context);
