@@ -13,9 +13,10 @@
 
 #include <QtCore/QString>
 
-#include "base/core.h"
+#include "base/ddcui_core.h"
 #include "base/ddca_utils.h"
 #include "base/global_state.h"
+
 #include "nongui/vcpthread.h"
 
 using namespace std;
@@ -212,17 +213,11 @@ DDCA_Status VcpThread::perform_open_display(DDCA_Display_Handle * dh_loc)
    debugFunc = debugFunc || debugThread;
    TRACECF(debugFunc, "Starting. dref=%s", ddca_dref_repr(this->_dref));
 
-   DDCA_Status ddcrc = ddca_open_display2(this->_dref, false, dh_loc);
+   DDCA_Status ddcrc = ddca_open_display2(this->_dref, true, dh_loc);
    // if (ddcrc == 0) ddcrc = -EBUSY;
    if (ddcrc != 0) {
        rpt_nonfeature_error("performing open", "ddca_open_display2", ddcrc);
    }
-   if (ddcrc == 0  && !_threadDescriptionPublished) {
-      TRACECF(debugFunc, "calling ddca_set_thread_description()");
-      // ddca_register_thread_dref(this->_dref);
-      ddca_append_thread_description( ddca_dref_repr(this->_dref) );
-      _threadDescriptionPublished = true;
-   }
    TRACECF(debugFunc, "Returning %d", ddcrc);
    return ddcrc;
 }
@@ -325,16 +320,17 @@ void VcpThread::capabilities() {
                                 ddca_dref_repr(this->_dref), ddca_rc_name(ddcrc));
             // DDCA_Error_Detail * err_detail =  ddca_get_error_detail();
             // ddca_report_error_detail(err_detail, 2);
-            double curmult = ddca_get_sleep_multiplier();
+            double curmult = 1.0f;
+            ddca_get_current_display_sleep_multiplier(this->_dref, &curmult);
             if (ddcrc == -EBADF) {
                TRACEC("EBADF");
                continue;
             }
 
             if (curmult <= 2.0f) {    // retry possible
-               curmult = curmult * 2;
-               TRACECF(debugRetry, "Adjusting thread sleep multiplier for %s to %5.2f",
-                                  ddca_dref_repr(this->_dref), curmult);
+               // curmult = curmult * 2;
+               // TRACECF(debugRetry, "Adjusting thread sleep multiplier for %s to %5.2f",
+               //                    ddca_dref_repr(this->_dref), curmult);
                // todo: output message in status bar that retrying
                // RETRYING DOESN"T HELP
                // ddca_set_sleep_multiplier(curmult);
@@ -408,21 +404,9 @@ void VcpThread::getvcp(uint8_t featureCode, bool needMetadata)
        }
        TRACECF(debugFunc, "feature_code=0x%02x, ddca_get_non_table_vcp_value() returned %d - %s",
                   featureCode, ddcrc, ddca_rc_name(ddcrc));
-       // don't need to call rpt_ddca_status() if error, error will be reported
-       // in the value field for the feature code
-#ifdef OLD
-        if (ddcrc != 0) {
+       // don't need to call rpt_ddca_status() here if error,
+       // error will be reported in the value field for the feature code
 
-           if (ddcrc != DDCRC_REPORTED_UNSUPPORTED) {
-              rpt_ddca_status(featureCode, __func__, "ddca_get_nontable_vcp_value", ddcrc);
-           }
-        }
-        else {
-            // printf("ddca_get_nontable_vcp_value() returned:\n");
-            // printf("  opcode:   0x%02x, mh=0x%02x, ml=0x%02x, sh=0x%02x, sl=0x%02x\n",
-            //        feature_code, valrec.mh, valrec.ml, valrec.sh, valrec.sl);
-        }
-#endif
       // if (ddcrc == 0) {  // if get_nontable_vcp_value() succeeded
            // TODO:  get metadata once and cache
            DDCA_Status ddcrc2 = ddca_get_feature_metadata_by_dh(
@@ -434,14 +418,11 @@ void VcpThread::getvcp(uint8_t featureCode, bool needMetadata)
                      featureCode, ddcrc2, ddca_rc_name(ddcrc2));
            // if (featureCode == 0xdf || featureCode == 0xf4 || featureCode == 0xf5)
            //       ddca_dbgrpt_feature_metadata(finfo, 1);
-
            // if (debugFunc && ddcrc2 == 0) {
-           //     // OLD: ddcui_dbgrpt_ddca_feature_metadata(finfo);
            //    ddca_dbgrpt_feature_metadata(finfo, 1);
            // }
            if (ddcrc2 != 0) {
-              rpt_feature_error(FeatureMetadata, featureCode, "ddca_get_capabilitis_string", ddcrc);
-              // cout << "ddca_get_feature_metadata() returned " << ddcrc << endl;
+              rpt_feature_error(FeatureMetadata, featureCode, "ddca_get_feature_data_by_dh", ddcrc);
            }
 
            // whether or not succeeded, set feature info in  _baseModel so FeatureValueWidget can display error
@@ -450,7 +431,6 @@ void VcpThread::getvcp(uint8_t featureCode, bool needMetadata)
            _baseModel->setFeatureChecked(featureCode);
        // }  // end, get value succeeded
 
-
        ddcrc = perform_close_display(dh);
     }  // open succeeded
     TRACECF(debugThread, "Done");
@@ -495,7 +475,6 @@ void VcpThread::setvcp(uint8_t feature_code, bool writeOnly, uint16_t shsl)
        if (ddcrc != 0) {
           TRACECF(debugFunc, "ddca_set_non_table_vcp_value() returned %d = %s", ddcrc, ddca_rc_name(ddcrc));
           rpt_feature_error(FeatureWrite, feature_code, "ddca_set_non_table_vcp_value", ddcrc);
-
           goto bye;
        }
        if (!writeOnly) {
@@ -515,7 +494,6 @@ void VcpThread::setvcp(uint8_t feature_code, bool writeOnly, uint16_t shsl)
                                    &valrec,
                                    &ddcrc);
            if (!simulated) {
-               // TRACEC("non-simulated");
                ddcrc = ddca_get_non_table_vcp_value(dh, feature_code, &valrec);
            }
            if (ddcrc != 0) {
@@ -536,10 +514,8 @@ void VcpThread::setvcp(uint8_t feature_code, bool writeOnly, uint16_t shsl)
                  ok = (sl == valrec.sl && sh == valrec.sh);
               }
               if (!ok) {
-                 // TRACE("Calling rpt_verify_error()");
                  rpt_verify_error(feature_code, "ddca_set_non_table_vcp_value", sh, sl, valrec.sh, valrec.sl);
-              }    // ddca_set_non_table_vcp_value() succeeded
-              // 10/2019 coming here even if verify error???
+              }
               TRACECF(debugFunc, "Calling _baseModel->modelVcpValueUpdate()");
               _baseModel->modelVcpValueUpdate(feature_code, valrec.sh, valrec.sl);
            }  // ddca_get_non_table_vcp_value() succeeded
